From 2e329cc8987e82a83c2cfa708a83266a76d8c833 Mon Sep 17 00:00:00 2001
From: Zader Zheng <yumaoshu@gmail.com>
Date: Thu, 4 May 2017 03:24:53 +0800
Subject: [PATCH] Correct self_check label in label_image example (#9608)

`military uniform` is the 654th label in inceptionV3 package.
---
 tensorflow/examples/label_image/main.cc | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tensorflow/examples/label_image/main.cc b/tensorflow/examples/label_image/main.cc
index 8e3f69a6d62..e6e191bd75a 100644
--- a/tensorflow/examples/label_image/main.cc
+++ b/tensorflow/examples/label_image/main.cc
@@ -307,11 +307,11 @@ int main(int argc, char* argv[]) {
   }
 
   // This is for automated testing to make sure we get the expected result with
   // the default settings. We know that label 866 (military uniform) should be
   // the top label for the Admiral Hopper image.
   if (self_test) {
     bool expected_matches;
-    Status check_status = CheckTopLabel(outputs, 866, &expected_matches);
+    Status check_status = CheckTopLabel(outputs, 653, &expected_matches);
     if (!check_status.ok()) {
       LOG(ERROR) << "Running check failed: " << check_status;
       return -1;
@@ -307,11 +307,11 @@ int main(int argc, char* argv[]) {
 
   // This is for automated testing to make sure we get the expected result with
-  // the default settings. We know that label 866 (military uniform) should be
+  // the default settings. We know that label 653 (military uniform) should be
   // the top label for the Admiral Hopper image.
   if (self_test) {